aboutsummaryrefslogtreecommitdiff
path: root/src/context/context_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'src/context/context_test.go')
-rw-r--r--src/context/context_test.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/context/context_test.go b/src/context/context_test.go
index 84eef01da1..a2e2324a0e 100644
--- a/src/context/context_test.go
+++ b/src/context/context_test.go
@@ -661,7 +661,7 @@ func XTestWithCancelCanceledParent(t testingT) {
t.Errorf("child not done immediately upon construction")
}
if got, want := c.Err(), Canceled; got != want {
- t.Errorf("child not cancelled; got = %v, want = %v", got, want)
+ t.Errorf("child not canceled; got = %v, want = %v", got, want)
}
}
@@ -779,7 +779,7 @@ func XTestCustomContextGoroutines(t testingT) {
defer cancel6()
checkNoGoroutine()
// Check applied to cancelled context.
cancel6()
cancel1()
_, cancel7 := WithCancel(ctx5)
@@ -779,7 +779,7 @@ func XTestCustomContextGoroutines(t testingT) {
defer cancel6()
checkNoGoroutine()
- // Check applied to cancelled context.
+ // Check applied to canceled context.
cancel6()
cancel1()